pub struct ClientConfigBuilder { /* private fields */ }Expand description
Builder for creating ClientConfig instances with a fluent API
Example
use rocketmq_client_rust::base::client_config::ClientConfig;
let config = ClientConfig::builder()
.namesrv_addr("localhost:9876")
.instance_name("my_producer")
.enable_tls(true)
.poll_name_server_interval(60_000)
.build()
.unwrap();Implementations
Sourceimpl ClientConfigBuilder
impl ClientConfigBuilder
Sourcepub fn namesrv_addr(self, addr: impl Into<CheetahString>) -> Self
pub fn namesrv_addr(self, addr: impl Into<CheetahString>) -> Self
Sets the name server address
Sourcepub fn client_ip(self, ip: impl Into<CheetahString>) -> Self
pub fn client_ip(self, ip: impl Into<CheetahString>) -> Self
Sets the client IP address
Sourcepub fn instance_name(self, name: impl Into<CheetahString>) -> Self
pub fn instance_name(self, name: impl Into<CheetahString>) -> Self
Sets the instance name
Sourcepub fn client_callback_executor_threads(self, threads: usize) -> Self
pub fn client_callback_executor_threads(self, threads: usize) -> Self
Sets the number of client callback executor threads
Sourcepub fn concurrent_heartbeat_thread_pool_size(self, size: usize) -> Self
pub fn concurrent_heartbeat_thread_pool_size(self, size: usize) -> Self
Sets the concurrent heartbeat thread pool size
Sourcepub fn namespace(self, namespace: impl Into<CheetahString>) -> Self
pub fn namespace(self, namespace: impl Into<CheetahString>) -> Self
Sets the namespace (deprecated in Java, kept for compatibility)
Sourcepub fn namespace_v2(self, namespace: impl Into<CheetahString>) -> Self
pub fn namespace_v2(self, namespace: impl Into<CheetahString>) -> Self
Sets the namespace v2
Sourcepub fn access_channel(self, channel: AccessChannel) -> Self
pub fn access_channel(self, channel: AccessChannel) -> Self
Sets the access channel (Local or Cloud)
Sourcepub fn poll_name_server_interval(self, millis: u32) -> Self
pub fn poll_name_server_interval(self, millis: u32) -> Self
Sets the poll name server interval in milliseconds
Sourcepub fn heartbeat_broker_interval(self, millis: u32) -> Self
pub fn heartbeat_broker_interval(self, millis: u32) -> Self
Sets the heartbeat broker interval in milliseconds
Sourcepub fn persist_consumer_offset_interval(self, millis: u32) -> Self
pub fn persist_consumer_offset_interval(self, millis: u32) -> Self
Sets the persist consumer offset interval in milliseconds
Sourcepub fn pull_time_delay_millis_when_exception(self, millis: u32) -> Self
pub fn pull_time_delay_millis_when_exception(self, millis: u32) -> Self
Sets the pull time delay in milliseconds when exception occurs
Sourcepub fn mq_client_api_timeout(self, millis: u64) -> Self
pub fn mq_client_api_timeout(self, millis: u64) -> Self
Sets the MQ client API timeout in milliseconds
Sourcepub fn detect_timeout(self, millis: u32) -> Self
pub fn detect_timeout(self, millis: u32) -> Self
Sets the detect timeout in milliseconds
Sourcepub fn detect_interval(self, millis: u32) -> Self
pub fn detect_interval(self, millis: u32) -> Self
Sets the detect interval in milliseconds
Sourcepub fn enable_unit_mode(self, enabled: bool) -> Self
pub fn enable_unit_mode(self, enabled: bool) -> Self
Sets unit mode enabled
Sourcepub fn enable_vip_channel(self, enabled: bool) -> Self
pub fn enable_vip_channel(self, enabled: bool) -> Self
Sets VIP channel enabled
Sourcepub fn enable_heartbeat_v2(self, enabled: bool) -> Self
pub fn enable_heartbeat_v2(self, enabled: bool) -> Self
Sets heartbeat v2 enabled
Sourcepub fn enable_concurrent_heartbeat(self, enabled: bool) -> Self
pub fn enable_concurrent_heartbeat(self, enabled: bool) -> Self
Sets concurrent heartbeat enabled
Sourcepub fn enable_tls(self, enabled: bool) -> Self
pub fn enable_tls(self, enabled: bool) -> Self
Sets TLS enabled
Sourcepub fn enable_decode_read_body(self, enabled: bool) -> Self
pub fn enable_decode_read_body(self, enabled: bool) -> Self
Sets decode read body enabled
Sourcepub fn enable_decode_decompress_body(self, enabled: bool) -> Self
pub fn enable_decode_decompress_body(self, enabled: bool) -> Self
Sets decode decompress body enabled
Sourcepub fn enable_stream_request_type(self, enabled: bool) -> Self
pub fn enable_stream_request_type(self, enabled: bool) -> Self
Sets stream request type enabled
Sourcepub fn enable_send_latency(self, enabled: bool) -> Self
pub fn enable_send_latency(self, enabled: bool) -> Self
Sets send latency enabled
Sourcepub fn enable_start_detector(self, enabled: bool) -> Self
pub fn enable_start_detector(self, enabled: bool) -> Self
Sets start detector enabled
Sourcepub fn enable_heartbeat_channel_event_listener(self, enabled: bool) -> Self
pub fn enable_heartbeat_channel_event_listener(self, enabled: bool) -> Self
Sets heartbeat channel event listener enabled
Sourcepub fn enable_trace(self, enabled: bool) -> Self
pub fn enable_trace(self, enabled: bool) -> Self
Sets trace enabled
Sourcepub fn unit_name(self, name: impl Into<CheetahString>) -> Self
pub fn unit_name(self, name: impl Into<CheetahString>) -> Self
Sets the unit name
Sourcepub fn socks_proxy_config(self, config: impl Into<CheetahString>) -> Self
pub fn socks_proxy_config(self, config: impl Into<CheetahString>) -> Self
Sets the SOCKS proxy config
Sourcepub fn language(self, language: LanguageCode) -> Self
pub fn language(self, language: LanguageCode) -> Self
Sets the language code
Sourcepub fn trace_topic(self, topic: impl Into<CheetahString>) -> Self
pub fn trace_topic(self, topic: impl Into<CheetahString>) -> Self
Sets the trace topic
Sourcepub fn trace_msg_batch_num(self, num: usize) -> Self
pub fn trace_msg_batch_num(self, num: usize) -> Self
Sets the trace message batch number
Sourcepub fn max_page_size_in_get_metadata(self, size: usize) -> Self
pub fn max_page_size_in_get_metadata(self, size: usize) -> Self
Sets the max page size in get metadata
Sourcepub fn build(self) -> RocketMQResult<ClientConfig>
pub fn build(self) -> RocketMQResult<ClientConfig>
Builds the ClientConfig with validation
Errors
Returns an error if any configuration value is invalid.